@@ -2,6 +2,7 @@
 Tests for CLI class.
 """
 
+import contextlib
 import sys
 from io import StringIO
 from unittest.mock import MagicMock, Mock, patch
@@ -179,7 +180,7 @@ class TestCLI:
         assert result == expected_response
 
         # Verify handle_request was called with correct input
-        self.cli.handle_request.assert_called_once_with(user_input)
+        self.cli.handle_request.assert_called_once_with(user_input, False)
 
     def test_clear_command_functionality(self):
         """Test that the clear command properly clears conversation history."""
@@ -199,69 +200,6 @@ class TestCLI:
                 # Verify success message was printed
                 mock_print.assert_called_once_with("Conversation history cleared.")
 
-    def test_history_command_functionality(self):
-        """Test that the history command displays conversation statistics."""
-        # Mock the conversation summary
-        summary = {
-            "total_messages": 10,
-            "user_messages": 4,
-            "assistant_messages": 4,
-            "tool_messages": 2,
-            "estimated_tokens": 250,
-            "thinking_time_count": 5,
-            "total_thinking_time": 8.5,
-            "average_thinking_time": 1.7,
-            "min_thinking_time": 0.5,
-            "max_thinking_time": 3.2,
-        }
-
-        self.cli.inference.get_conversation_summary.return_value = summary
-
-        with patch("builtins.print") as mock_print:
-            # Simulate the history command logic
-            summary_output = self.cli.inference.get_conversation_summary()
-            print("Conversation Stats:")
-            print(f"  Total messages: {summary_output['total_messages']}")
-            print(f"  User messages: {summary_output['user_messages']}")
-            print(f"  Assistant messages: {summary_output['assistant_messages']}")
-            print(f"  Tool messages: {summary_output['tool_messages']}")
-            print(f"  Estimated tokens: {summary_output['estimated_tokens']}")
-            print("  Thinking time stats:")
-            print(
-                f"    Total thinking time: {summary_output['total_thinking_time']:.2f}s"
-            )
-            print(
-                f"    Average thinking time: {summary_output['average_thinking_time']:.2f}s"
-            )
-            print(f"    Min thinking time: {summary_output['min_thinking_time']:.2f}s")
-            print(f"    Max thinking time: {summary_output['max_thinking_time']:.2f}s")
-            print(f"    Requests with timing: {summary_output['thinking_time_count']}")
-
-            # Verify get_conversation_summary was called
-            self.cli.inference.get_conversation_summary.assert_called_once()
-
-            # Verify all expected print calls
-            expected_calls = [
-                "Conversation Stats:",
-                "  Total messages: 10",
-                "  User messages: 4",
-                "  Assistant messages: 4",
-                "  Tool messages: 2",
-                "  Estimated tokens: 250",
-                "  Thinking time stats:",
-                "    Total thinking time: 8.50s",
-                "    Average thinking time: 1.70s",
-                "    Min thinking time: 0.50s",
-                "    Max thinking time: 3.20s",
-                "    Requests with timing: 5",
-            ]
-
-            # Check that all expected calls were made
-            for expected_call in expected_calls:
-                assert any(
-                    expected_call in str(call) for call in mock_print.call_args_list
-                )
-
     def test_list_command_success(self):
         """Test successful list command execution."""
         expected_output = "1 Buy groceries\n2 Call mom\n3 Review project"
@@ -352,10 +290,9 @@ class TestCLI:
             # Simulate the help command logic
             print("Available commands:")
             print("  clear    - Clear conversation history")
-            print("  history  - Show conversation statistics")
             print("  help     - Show this help message")
-            print("  list     - List all tasks (no LLM interaction)")
-            print("  done     - List completed tasks (no LLM interaction)")
+            print("  list     - List all tasks")
+            print("  done     - List completed tasks")
             print("  quit     - Exit the application")
             print("  Or just type your request naturally!")
 
@@ -363,10 +300,9 @@ class TestCLI:
             expected_help_lines = [
                 "Available commands:",
                 "  clear    - Clear conversation history",
-                "  history  - Show conversation statistics",
                 "  help     - Show this help message",
-                "  list     - List all tasks (no LLM interaction)",
-                "  done     - List completed tasks (no LLM interaction)",
+                "  list     - List all tasks",
+                "  done     - List completed tasks",
                 "  quit     - Exit the application",
                 "  Or just type your request naturally!",
             ]
@@ -377,6 +313,97 @@ class TestCLI:
                     expected_line in str(call) for call in mock_print.call_args_list
                 )
 
+    def test_todo_passthrough_command_success(self):
+        """Test successful todo.sh passthrough command execution."""
+        with patch("builtins.input", return_value="/add test task"), patch("sys.exit"):
+            # Mock the todo_shell execute method
+            mock_todo_shell = Mock()
+            mock_todo_shell.execute.return_value = "1 test task"
+
+            # Create CLI instance with mocked dependencies
+            with patch("todo_agent.interface.cli.Config"), patch(
+                "todo_agent.interface.cli.TodoShell", return_value=mock_todo_shell
+            ), patch("todo_agent.interface.cli.TodoManager"), patch(
+                "todo_agent.interface.cli.ToolCallHandler"
+            ), patch("todo_agent.interface.cli.Inference"), patch(
+                "todo_agent.interface.cli.Logger"
+            ), patch("todo_agent.interface.cli.Console") as mock_console:
+                CLI()
+
+                # Mock the console methods
+                mock_console.return_value.input.return_value = "/add test task"
+                mock_console.return_value.print = Mock()
+
+                # Test the passthrough logic directly
+                user_input = "/add test task"
+                if user_input.startswith("/"):
+                    todo_command = user_input[1:].strip()
+                    output = mock_todo_shell.execute(["todo.sh", *todo_command.split()])
+
+                    # Verify the command was executed correctly
+                    mock_todo_shell.execute.assert_called_once_with(
+                        ["todo.sh", "add", "test", "task"]
+                    )
+                    assert output == "1 test task"
+
+    def test_todo_passthrough_command_empty(self):
+        """Test todo.sh passthrough with empty command."""
+        with patch("builtins.input", return_value="/"), patch("sys.exit"):
+            # Mock the todo_shell execute method
+            mock_todo_shell = Mock()
+
+            # Create CLI instance with mocked dependencies
+            with patch("todo_agent.interface.cli.Config"), patch(
+                "todo_agent.interface.cli.TodoShell", return_value=mock_todo_shell
+            ), patch("todo_agent.interface.cli.TodoManager"), patch(
+                "todo_agent.interface.cli.ToolCallHandler"
+            ), patch("todo_agent.interface.cli.Inference"), patch(
+                "todo_agent.interface.cli.Logger"
+            ), patch("todo_agent.interface.cli.Console") as mock_console:
+                CLI()
+
+                # Mock the console methods
+                mock_console.return_value.input.return_value = "/"
+                mock_console.return_value.print = Mock()
+
+                # Test the passthrough logic with empty command
+                user_input = "/"
+                if user_input.startswith("/"):
+                    todo_command = user_input[1:].strip()
+                    if not todo_command:
+                        # Should handle empty command gracefully
+                        assert todo_command == ""
+
+    def test_todo_help_command(self):
+        """Test todo-help command execution."""
+        with patch("builtins.input", return_value="todo-help"), patch("sys.exit"):
+            # Mock the todo_shell get_help method
+            mock_todo_shell = Mock()
+            mock_todo_shell.get_help.return_value = "Todo.sh help output"
+
+            # Create CLI instance with mocked dependencies
+            with patch("todo_agent.interface.cli.Config"), patch(
+                "todo_agent.interface.cli.TodoShell", return_value=mock_todo_shell
+            ), patch("todo_agent.interface.cli.TodoManager"), patch(
+                "todo_agent.interface.cli.ToolCallHandler"
+            ), patch("todo_agent.interface.cli.Inference"), patch(
+                "todo_agent.interface.cli.Logger"
+            ), patch("todo_agent.interface.cli.Console") as mock_console:
+                CLI()
+
+                # Mock the console methods
+                mock_console.return_value.input.return_value = "todo-help"
+                mock_console.return_value.print = Mock()
+
+                # Test the todo-help command
+                user_input = "todo-help"
+                if user_input.lower() == "todo-help":
+                    help_output = mock_todo_shell.get_help()
+
+                    # Verify the help was retrieved
+                    mock_todo_shell.get_help.assert_called_once()
+                    assert help_output == "Todo.sh help output"
+
     def test_empty_input_handling(self):
         """Test that empty input is handled gracefully."""
         # This would be tested in the main run loop
@@ -425,3 +452,16 @@ class TestCLI:
         # Verify live display was created
         assert live_display is not None
         assert hasattr(live_display, "console")
+
+    @patch("todo_agent.interface.cli.CLI._print_header")
+    def test_keyboard_interrupt_at_prompt(self, mock_print_header):
+        """Test that KeyboardInterrupt at prompt is handled gracefully."""
+        # Mock console.input to raise KeyboardInterrupt
+        with patch.object(self.cli.console, "input", side_effect=KeyboardInterrupt):
+            with patch.object(self.cli.console, "print") as mock_print:
+                # This should not raise an exception and should exit cleanly
+                with contextlib.suppress(SystemExit):
+                    self.cli.run()
+
+                # Verify that the goodbye message was printed
+                mock_print.assert_any_call("\n[bold green]Goodbye! 👋[/bold green]")
