@@ -3,6 +3,7 @@ LLM inference engine for todo.sh agent.
 """
 
 import os
+import signal
 import time
 from datetime import datetime
 from typing import Any, Dict, Optional
@@ -57,12 +58,14 @@ class Inference:
         self.config = config
         self.tool_handler = tool_handler
         self.logger = logger or Logger("inference")
+        self.use_mini_prompt = config.use_mini_prompt
 
-        # Initialize LLM client using factory
         self.llm_client = LLMClientFactory.create_client(config, self.logger)
-
-        # Initialize conversation manager
         self.conversation_manager = ConversationManager()
+        self._cancelled = False
+
+        # Set up signal handler for user interruption (Ctrl+C)
+        signal.signal(signal.SIGINT, self._handle_interrupt)
 
         # Set up system prompt
         self._setup_system_prompt()
@@ -71,6 +74,44 @@ class Inference:
             f"Inference engine initialized with {config.provider} provider using model: {self.llm_client.get_model_name()}"
         )
 
+    def _handle_interrupt(self, signum: int, frame: Any) -> None:
+        """
+        Handle user interruption signal (Ctrl+C).
+
+        Args:
+            signum: Signal number (should be SIGINT)
+            frame: Current stack frame
+        """
+        self._cancelled = True
+        self.logger.info("User interruption signal received (Ctrl+C)")
+        # Don't exit immediately - let current operation finish gracefully
+
+    def _handle_cancellation(self, start_time: float) -> tuple[str, float]:
+        """
+        Handle cancellation by adding "I stopped." message to conversation.
+
+        Args:
+            start_time: Request start time for calculating thinking time
+
+        Returns:
+            Tuple of (cancellation message, actual thinking time)
+        """
+        # Calculate actual thinking time
+        end_time = time.time()
+        thinking_time = end_time - start_time
+
+        self.conversation_manager.add_message(MessageRole.ASSISTANT, "I stopped.")
+        self._cancelled = False
+        return "I stopped.", thinking_time
+
+    def reset_cancellation_flag(self) -> None:
+        """
+        Reset the cancellation flag. Call this before starting a new request
+        to ensure any previous cancellation state is cleared.
+        """
+        self._cancelled = False
+        self.logger.debug("Cancellation flag reset")
+
     def _setup_system_prompt(self) -> None:
         """Set up the system prompt for the LLM."""
         system_prompt = self._load_system_prompt()
@@ -118,8 +159,11 @@ class Inference:
         current_tasks = self.current_tasks()
 
         # Load system prompt from file
+        prompt_filename = (
+            "system_prompt_small.txt" if self.use_mini_prompt else "system_prompt.txt"
+        )
         prompt_file_path = os.path.join(
-            os.path.dirname(__file__), "prompts", "system_prompt.txt"
+            os.path.dirname(__file__), "prompts", prompt_filename
         )
 
         try:
@@ -141,7 +185,10 @@ class Inference:
             raise
 
     def process_request(
-        self, user_input: str, progress_callback: Optional[ToolCallProgress] = None
+        self,
+        user_input: str,
+        progress_callback: Optional[ToolCallProgress] = None,
+        system_request: bool = False,
     ) -> tuple[str, float]:
         """
         Process a user request through the LLM with tool orchestration.
@@ -149,6 +196,7 @@ class Inference:
         Args:
             user_input: Natural language user request
             progress_callback: Optional progress callback for tool call tracking
+            system_request: If True, treat the input as a system message instead of user message
 
         Returns:
             Tuple of (formatted response for user, thinking time in seconds)
@@ -168,9 +216,10 @@ class Inference:
                 f"Starting request processing for: {user_input[:30]}{'...' if len(user_input) > 30 else ''}"
             )
 
-            # Add user message to conversation
-            self.conversation_manager.add_message(MessageRole.USER, user_input)
-            self.logger.debug("Added user message to conversation")
+            # Add message to conversation (user or system based on flag)
+            message_role = MessageRole.SYSTEM if system_request else MessageRole.USER
+            self.conversation_manager.add_message(message_role, user_input)
+            self.logger.debug(f"Added {message_role.value} message to conversation")
 
             # Get conversation history for LLM
             messages = self.conversation_manager.get_messages()
@@ -178,12 +227,24 @@ class Inference:
                 f"Retrieved {len(messages)} messages from conversation history"
             )
 
+            # Check for cancellation before LLM API call
+            if self._cancelled:
+                self.logger.info("Request cancelled before LLM API call")
+                return self._handle_cancellation(start_time)
+
             # Send to LLM with function calling enabled
             self.logger.debug("Sending request to LLM with tools")
             response = self.llm_client.chat_with_tools(
-                messages=messages, tools=self.tool_handler.tools
+                messages=messages,
+                tools=self.tool_handler.tools,
+                cancelled=self._cancelled,
             )
 
+            # Check for cancellation after LLM response received
+            if self._cancelled:
+                self.logger.info("Request cancelled after LLM response received")  # type: ignore
+                return self._handle_cancellation(start_time)
+
             # Check for provider errors
             if response.get("error", False):
                 error_type = response.get("error_type", "general_error")
@@ -238,6 +299,13 @@ class Inference:
                 # Execute all tool calls and collect results
                 tool_results = []
                 for i, tool_call in enumerate(tool_calls):
+                    # Check for cancellation before each tool execution
+                    if self._cancelled:
+                        self.logger.info(  # type: ignore
+                            f"Request cancelled before tool execution #{i + 1}"
+                        )
+                        return self._handle_cancellation(start_time)
+
                     tool_name = tool_call.get("function", {}).get("name", "unknown")
                     tool_call_id = tool_call.get("id", "unknown")
                     self.logger.debug(
@@ -273,6 +341,20 @@ class Inference:
                     self.logger.debug(f"Tool result: {result}")
                     tool_results.append(result)
 
+                    # Check for cancellation after each tool execution completes
+                    if self._cancelled:
+                        self.logger.info(  # type: ignore
+                            f"Request cancelled after tool execution #{i + 1}"
+                        )
+                        return self._handle_cancellation(start_time)
+
+                # Check for cancellation before adding tool results to conversation
+                if self._cancelled:
+                    self.logger.info(  # type: ignore
+                        "Request cancelled before adding tool results to conversation"
+                    )
+                    return self._handle_cancellation(start_time)
+
                 # Add tool call sequence to conversation
                 self.conversation_manager.add_tool_call_sequence(
                     tool_calls, tool_results
@@ -282,13 +364,23 @@ class Inference:
                 # Continue conversation with tool results
                 messages = self.conversation_manager.get_messages()
                 response = self.llm_client.chat_with_tools(
-                    messages=messages, tools=self.tool_handler.tools
+                    messages=messages,
+                    tools=self.tool_handler.tools,
+                    cancelled=self._cancelled,
                 )
 
                 # Check for provider errors in continuation
                 if response.get("error", False):
                     error_type = response.get("error_type", "general_error")
                     provider = response.get("provider", "unknown")
+
+                    # Handle cancellation specially
+                    if error_type == "cancelled":
+                        self.logger.info(
+                            f"Request cancelled in continuation from {provider}"
+                        )
+                        return self._handle_cancellation(start_time)
+
                     self.logger.error(
                         f"Provider error in continuation from {provider}: {error_type}"
                     )
@@ -413,6 +505,24 @@ class Inference:
         self.conversation_manager.clear_conversation()
         self.logger.info("Conversation history cleared")
 
+    def add_system_message(self, content: str) -> None:
+        """
+        Add a system message to the conversation.
+
+        Args:
+            content: The system message content
+        """
+        self.conversation_manager.add_message(MessageRole.SYSTEM, content)
+
+    def add_user_message(self, content: str) -> None:
+        """
+        Add a user message to the conversation.
+
+        Args:
+            content: The user message content
+        """
+        self.conversation_manager.add_message(MessageRole.USER, content)
+
     def get_conversation_manager(self) -> ConversationManager:
         """
         Get the conversation manager instance.
