@@ -81,7 +81,16 @@ class TodoShell:
                 from rich.text import Text
 
                 # Use Rich's Text.from_ansi to parse and then get plain text
-                output = Text.from_ansi(output).plain
+                try:
+                    plain_output = Text.from_ansi(output).plain
+                    output = plain_output
+                except Exception as e:
+                    if self.logger:
+                        self.logger.warning(
+                            f"Failed to strip ANSI codes using Rich: {e}, falling back to original output"
+                        )
+                    # Fallback: keep original output if Rich processing fails
+
                 if self.logger:
                     self.logger.debug(
                         f"Stripped ANSI codes from output for LLM consumption"
@@ -182,6 +191,10 @@ class TodoShell:
         """Archive completed tasks."""
         return self.execute(["todo.sh", "-f", "archive"])
 
+    def get_help(self) -> str:
+        """Get todo.sh help output."""
+        return self.execute(["todo.sh", "help"], suppress_color=False)
+
     def set_due_date(self, task_number: int, due_date: str) -> str:
         """
         Set or update due date for a task by intelligently rewriting it.
