@@ -2,7 +2,9 @@
 Command-line interface for todo.sh LLM agent.
 """
 
+import os
 import readline
+from datetime import datetime
 from typing import Optional
 
 from rich.align import Align
@@ -21,7 +23,6 @@ try:
         CLI_WIDTH,
         PanelFormatter,
         ResponseFormatter,
-        TableFormatter,
         TaskFormatter,
     )
     from todo_agent.interface.progress import ToolCallProgress
@@ -36,7 +37,6 @@ except ImportError:
         CLI_WIDTH,
         PanelFormatter,
         ResponseFormatter,
-        TableFormatter,
         TaskFormatter,
     )
     from interface.progress import ToolCallProgress  # type: ignore[no-redef]
@@ -79,6 +79,26 @@ class CLI:
 
         self.logger.info("CLI initialization completed")
 
+    def _load_review_prompt(self) -> str:
+        """Load the review prompt from file."""
+        prompt_file_path = os.path.join(
+            os.path.dirname(__file__),
+            "..",
+            "infrastructure",
+            "prompts",
+            "review_prompt.txt",
+        )
+
+        try:
+            with open(prompt_file_path, encoding="utf-8") as f:
+                return f.read()
+        except FileNotFoundError:
+            self.logger.error(f"Review prompt file not found: {prompt_file_path}")
+            raise
+        except Exception as e:
+            self.logger.error(f"Error loading review prompt: {e!s}")
+            raise
+
     def _create_thinking_spinner(self, message: str = "Thinking...") -> Spinner:
         """
         Create a thinking spinner with the given message.
@@ -220,21 +240,32 @@ class CLI:
         self.console.print(Align.center(subtitle), style="dim")
 
     def _print_help(self) -> None:
-        """Print help information in a formatted table."""
-        table = TableFormatter.create_command_table()
-        self.console.print(table)
-        self.console.print("Or just type your request naturally!", style="italic green")
+        """Print help information in a formatted panel."""
+        help_panel = PanelFormatter.create_help_panel()
+        self.console.print(help_panel)
+
+    def _print_todo_help(self) -> None:
+        """Print todo.sh help information."""
+        try:
+            # Get todo.sh help output
+            help_output = self.todo_shell.get_help()
+            formatted_output = TaskFormatter.format_task_list(help_output)
+            help_panel = PanelFormatter.create_task_panel(
+                formatted_output, title="📋 Todo.sh Help"
+            )
+            self.console.print(help_panel)
+        except Exception as e:
+            self.logger.error(f"Error getting todo.sh help: {e!s}")
+            error_msg = ResponseFormatter.format_error(
+                f"Failed to get todo.sh help: {e!s}"
+            )
+            self.console.print(error_msg)
 
     def _print_about(self) -> None:
         """Print about information in a formatted panel."""
         about_panel = PanelFormatter.create_about_panel()
         self.console.print(about_panel)
 
-    def _print_stats(self, summary: dict) -> None:
-        """Print conversation statistics in a formatted table."""
-        table = TableFormatter.create_stats_table(summary)
-        self.console.print(table)
-
     def _get_memory_usage(self) -> Optional[Text]:
         """Get session memory usage as a progress bar."""
         # Get conversation manager to access memory limits and current usage
@@ -266,12 +297,25 @@ class CLI:
         # Print separator
         self.console.print("─" * CLI_WIDTH, style="dim")
 
+        # Prime conversation with today's date
+        today = datetime.now()
+        self.inference.add_user_message(f"Today is {today.strftime('%A, %Y-%m-%d')}.")
+
         while True:
             try:
                 # Print prompt character on separate line to prevent deletion
                 self.console.print("\n[bold cyan]▶[/bold cyan]", end=" ")
                 user_input = self.console.input().strip()
+            except KeyboardInterrupt:
+                self.logger.info("User interrupted with Ctrl+C at prompt")
+                self.console.print("\n[bold green]Goodbye! 👋[/bold green]")
+                break
+            except EOFError:
+                self.logger.info("Input stream ended (EOF)")
+                self.console.print("\n[bold green]Goodbye! 👋[/bold green]")
+                break
 
+            try:
                 if user_input.lower() in ["quit", "exit", "q"]:
                     self.logger.info("User requested exit")
                     self.console.print("\n[bold green]Goodbye! 👋[/bold green]")
@@ -280,6 +324,37 @@ class CLI:
                 if not user_input:
                     continue
 
+                # Handle todo.sh passthrough commands (starting with /)
+                if user_input.startswith("/"):
+                    self.logger.debug(
+                        f"Processing todo.sh passthrough command: {user_input}"
+                    )
+                    try:
+                        # Remove the leading / and execute as todo.sh command
+                        todo_command = user_input[1:].strip()
+                        if not todo_command:
+                            self.console.print(
+                                ResponseFormatter.format_error("Empty todo.sh command")
+                            )
+                            continue
+
+                        # Execute the todo.sh command directly
+                        output = self.todo_shell.execute(
+                            ["todo.sh", *todo_command.split()]
+                        )
+                        formatted_output = TaskFormatter.format_task_list(output)
+                        task_panel = PanelFormatter.create_task_panel(
+                            formatted_output, title="📋 Todo.sh Output"
+                        )
+                        self.console.print(task_panel)
+                    except Exception as e:
+                        self.logger.error(f"Error executing todo.sh command: {e!s}")
+                        error_msg = ResponseFormatter.format_error(
+                            f"Todo.sh command failed: {e!s}"
+                        )
+                        self.console.print(error_msg)
+                    continue
+
                 # Handle special commands
                 if user_input.lower() == "clear":
                     self.logger.info("User requested conversation clear")
@@ -291,17 +366,16 @@ class CLI:
                     )
                     continue
 
-                if user_input.lower() == "stats":
-                    self.logger.debug("User requested conversation stats")
-                    summary = self.inference.get_conversation_summary()
-                    self._print_stats(summary)
-                    continue
-
                 if user_input.lower() == "help":
                     self.logger.debug("User requested help")
                     self._print_help()
                     continue
 
+                if user_input.lower() == "todo-help":
+                    self.logger.debug("User requested todo.sh help")
+                    self._print_todo_help()
+                    continue
+
                 if user_input.lower() == "about":
                     self.logger.debug("User requested about information")
                     self._print_about()
@@ -344,15 +418,22 @@ class CLI:
                 self.logger.info(
                     f"Processing user request: {user_input[:50]}{'...' if len(user_input) > 50 else ''}"
                 )
+
+                # This is a natural language request
+
+                # Perform the first pass of the response
                 response = self.handle_request(user_input)
 
+                # Second pass: provide the best possible response as if this is the first answer
+                # review_prompt = self._load_review_prompt()
+                # response = self.handle_request(review_prompt, system_request=True)
+
                 # Format the response and create a panel
                 formatted_response = ResponseFormatter.format_response(response)
 
                 # Get memory usage
-                # DISABLED FOR NOW
-                memory_usage = self._get_memory_usage()
-                # memory_usage = None
+                # memory_usage = self._get_memory_usage()
+                memory_usage = None
 
                 # Create response panel with memory usage
                 response_panel = PanelFormatter.create_response_panel(
@@ -361,35 +442,46 @@ class CLI:
                 self.console.print(response_panel)
 
             except KeyboardInterrupt:
-                self.logger.info("User interrupted with Ctrl+C")
+                self.logger.info(
+                    "User interrupted with Ctrl+C during request processing"
+                )
                 self.console.print("\n[bold green]Goodbye! 👋[/bold green]")
                 break
             except Exception as e:
-                self.logger.error(f"Error in CLI loop: {e!s}")
+                self.logger.error(f"Error processing request: {e!s}")
                 error_msg = ResponseFormatter.format_error(str(e))
                 self.console.print(error_msg)
 
-    def handle_request(self, user_input: str) -> str:
+    def handle_request(self, user_input: str, system_request: bool = False) -> str:
         """
         Handle user request with LLM-driven tool orchestration and conversation memory.
 
         Args:
             user_input: Natural language user request
+            system_request: If True, treat the input as a system message instead of user message
 
         Returns:
             Formatted response for user
         """
+        # Reset cancellation flag before processing request
+        self.inference.reset_cancellation_flag()
+
         # Show thinking spinner during LLM processing
         with self._get_thinking_live() as live:
             try:
                 # Create progress callback for tool call tracking
                 progress_callback = self._create_cli_progress_callback(live)
 
-                # Process request through inference engine with progress tracking
+                # First pass: Process user request
                 response, thinking_time = self.inference.process_request(
-                    user_input, progress_callback
+                    user_input, progress_callback, system_request
                 )
 
+                # # Second pass: Refine the response
+                # review_prompt = self._load_review_prompt()
+                # response, thinking_time2 = self.inference.process_request(review_prompt, progress_callback, system_request=True)
+                # thinking_time = thinking_time + thinking_time2
+
                 # Update spinner with completion message and thinking time
                 live.update(
                     self._create_thinking_spinner(f"(thought for {thinking_time:.1f}s)")
@@ -406,17 +498,20 @@ class CLI:
                 # Return error message
                 return ResponseFormatter.format_error(str(e))
 
-    def run_single_request(self, user_input: str) -> str:
+    def run_single_request(
+        self, input_prompt: str, system_request: bool = False
+    ) -> str:
         """
         Run a single request without entering the interactive loop.
 
         Args:
             user_input: Natural language user request
+            system_request: If True, treat the input as a system message instead of user message
 
         Returns:
             Formatted response
         """
         self.logger.info(
-            f"Running single request: {user_input[:50]}{'...' if len(user_input) > 50 else ''}"
+            f"Running single request: {input_prompt[:50]}{'...' if len(input_prompt) > 50 else ''}"
         )
-        return self.handle_request(user_input)
+        return self.handle_request(input_prompt, system_request)
