@@ -2,12 +2,11 @@
 Formatters for CLI output with unicode characters and consistent styling.
 """
 
-from typing import Any, Dict, Optional
+from typing import Optional
 
 from rich.align import Align
 from rich.box import ROUNDED
 from rich.panel import Panel
-from rich.table import Table
 from rich.text import Text
 
 # CLI width configuration
@@ -244,37 +243,14 @@ class ResponseFormatter:
     @staticmethod
     def format_response(response: str) -> str:
         """
-        Format an LLM response with consistent styling.
+        Format am LLM response.
 
         Args:
             response: Raw response text
-            title: Title for the response panel
 
         Returns:
             Formatted response string
         """
-        # If response contains task lists, format them nicely
-        if "No tasks found" in response or "1." in response:
-            # This might be a task list response, try to format it
-            lines = response.split("\n")
-            formatted_lines = []
-
-            for line in lines:
-                if line.strip().startswith(
-                    ("1.", "2.", "3.", "4.", "5.", "6.", "7.", "8.", "9.")
-                ):
-                    # This looks like a numbered task list, format it
-                    parts = line.split(".", 1)
-                    if len(parts) == 2:
-                        number = parts[0].strip()
-                        content = parts[1].strip()
-                        formatted_lines.append(f"  {number:>2} │ {content}")
-                    else:
-                        formatted_lines.append(line)
-                else:
-                    formatted_lines.append(line)
-
-            return "\n".join(formatted_lines)
 
         return response
 
@@ -336,75 +312,6 @@ class StatsFormatter:
         return overview
 
 
-class TableFormatter:
-    """Creates rich tables for various data displays."""
-
-    @staticmethod
-    def create_command_table() -> Table:
-        """Create a table for displaying available commands."""
-        table = Table(
-            title="Available Commands",
-            box=ROUNDED,
-            show_header=True,
-            header_style="bold magenta",
-            width=PANEL_WIDTH,
-        )
-
-        table.add_column("Command", style="cyan", width=12)
-        table.add_column("Description", style="white")
-
-        commands = [
-            ("clear", "Clear conversation history"),
-            ("stats", "Show conversation statistics"),
-            ("help", "Show this help message"),
-            ("about", "Show application information"),
-            ("list", "List all tasks (no LLM interaction)"),
-            ("done", "List completed tasks (no LLM interaction)"),
-            ("quit", "Exit the application"),
-        ]
-
-        for cmd, desc in commands:
-            table.add_row(cmd, desc)
-
-        return table
-
-    @staticmethod
-    def create_stats_table(summary: Dict[str, Any]) -> Table:
-        """Create a table for displaying conversation statistics."""
-        table = Table(
-            title="Conversation Statistics",
-            box=ROUNDED,
-            show_header=True,
-            header_style="bold magenta",
-            width=PANEL_WIDTH,
-        )
-
-        table.add_column("Metric", style="cyan", width=20)
-        table.add_column("Value", style="white")
-
-        # Basic stats
-        table.add_row("Total Messages", str(summary["total_messages"]))
-        table.add_row("User Messages", str(summary["user_messages"]))
-        table.add_row("Assistant Messages", str(summary["assistant_messages"]))
-        table.add_row("Tool Messages", str(summary["tool_messages"]))
-        table.add_row("Estimated Tokens", str(summary["estimated_tokens"]))
-
-        # Thinking time stats if available
-        if "thinking_time_count" in summary and summary["thinking_time_count"] > 0:
-            table.add_row("", "")  # Empty row for spacing
-            table.add_row(
-                "Total Thinking Time", f"{summary['total_thinking_time']:.2f}s"
-            )
-            table.add_row(
-                "Average Thinking Time", f"{summary['average_thinking_time']:.2f}s"
-            )
-            table.add_row("Min Thinking Time", f"{summary['min_thinking_time']:.2f}s")
-            table.add_row("Max Thinking Time", f"{summary['max_thinking_time']:.2f}s")
-            table.add_row("Requests with Timing", str(summary["thinking_time_count"]))
-
-        return table
-
-
 class PanelFormatter:
     """Creates rich panels for various content displays."""
 
@@ -501,6 +408,42 @@ class PanelFormatter:
             width=PANEL_WIDTH + 2,
         )
 
+    @staticmethod
+    def create_help_panel() -> Panel:
+        """Create a panel for displaying help information."""
+        help_content = Text()
+        help_content.append("Available Commands\n", style="bold blue")
+        help_content.append("\n")
+
+        # Add commands in a formatted list
+        commands = [
+            ("help", "Show this help message"),
+            ("quit", "Exit the application"),
+            ("list", "List all tasks"),
+            ("done", "List completed tasks"),
+            ("clear", "Clear conversation history"),
+            ("/[cmd] [args]", "Direct todo.sh access: /add 'task'"),
+            ("todo-help", "Show todo.sh help"),
+            ("about", "Show application information"),
+        ]
+
+        for cmd, desc in commands:
+            help_content.append(f"{cmd:<12} ", style="cyan")
+            help_content.append(f"{desc}\n", style="white")
+
+        help_content.append("\n")
+        help_content.append(
+            "Or just type your request naturally!", style="italic green"
+        )
+
+        return Panel(
+            Align.center(help_content),
+            title="?  Help",
+            border_style="dim",
+            box=ROUNDED,
+            width=PANEL_WIDTH + 2,
+        )
+
     @staticmethod
     def create_memory_usage_bar(
         current_tokens: int, max_tokens: int, current_messages: int, max_messages: int
