@@ -26,13 +26,15 @@ Task Modification Tools:
 - set_due_date(task_number, due_date) - Set or update due date for a task by intelligently rewriting it (use empty string to remove due date)
 - set_context(task_number, context) - Set or update context for a task by intelligently rewriting it (use empty string to remove context)
 - set_project(task_number, projects) - Set or update projects for a task by intelligently rewriting it (handles array of projects with add/remove operations)
-- set_parent(task_number, parent_number) - Set or update parent task number for a task by intelligently rewriting it (use None to remove parent)
 
 Utility Tools:
 - move_task(task_number, destination, source?) - Move task between files
 - archive_tasks() - Archive completed tasks from todo.txt to done.txt
 - get_calendar(month, year) - Get calendar for specific month and year
 - parse_date(date_expression) - Convert natural language date expressions to YYYY-MM-DD format
+
+Mathematical Reasoning Tools:
+- solve_math(expression, operation?) - Perform mathematical calculations and symbolic reasoning using SymPy
 """
 
 import subprocess
@@ -41,9 +43,11 @@ from typing import Any, Callable, Dict, List, Optional
 try:
     from todo_agent.core.todo_manager import TodoManager
     from todo_agent.infrastructure.logger import Logger
+    from todo_agent.infrastructure.math_solver import MathSolver
 except ImportError:
     from core.todo_manager import TodoManager  # type: ignore[no-redef]
     from infrastructure.logger import Logger  # type: ignore[no-redef]
+    from infrastructure.math_solver import MathSolver  # type: ignore[no-redef]
 
 
 class ToolCallHandler:
@@ -52,6 +56,7 @@ class ToolCallHandler:
     def __init__(self, todo_manager: TodoManager, logger: Optional[Logger] = None):
         self.todo_manager = todo_manager
         self.logger = logger
+        self.math_solver = MathSolver()
         self.tools = self._define_tools()
 
     def _define_tools(self) -> List[Dict[str, Any]]:
@@ -136,7 +141,7 @@ class ToolCallHandler:
                         "Add a NEW task to todo.txt with intelligent automatic inference capabilities. "
                         "USE CASE: Call this when user wants to create a NEW task, not when they want to complete, modify, or work with existing tasks. "
                         "CRITICAL: Before adding ANY task, you MUST use list_tasks() and list_completed_tasks() to check for potential duplicates. "
-                        "Look for tasks with similar descriptions, keywords, or intent. If you find similar tasks, "
+                        "Look for tasks with similar descriptions, keywords, or intent. If you find tasks that seem to be DUPLICATIVE, "
                         "ask the user if they want to add a new task or modify an existing one. "
                         "INTELLIGENT INFERENCE ENGINE: This tool automatically infers missing elements to create complete, actionable tasks: "
                         "PROJECT INFERENCE: Automatically detect and add appropriate +project tags based on task keywords, semantic patterns, and existing project usage. "
@@ -145,7 +150,6 @@ class ToolCallHandler:
                         "Apply strategic timing based on task type, work patterns, personal schedules, and existing due date patterns. "
                         "DURATION INFERENCE: Automatically estimate appropriate duration: tags based on task complexity, context, and historical patterns. "
                         "PRIORITY INFERENCE: Suggest appropriate priority levels (A-Z) based on urgency, importance, and existing priority patterns. "
-                        "Only ask for clarification when genuinely ambiguous. Always provide a complete, natural response to the user. "
                         "STRATEGIC CONTEXT: This is a CREATION tool - call this LAST after using "
                         "discovery tools (list_tasks, list_projects, list_contexts, list_completed_tasks) "
                         "to gather all necessary context and verify no duplicates exist."
@@ -177,10 +181,6 @@ class ToolCallHandler:
                                 "type": "string",
                                 "description": "Optional duration estimate in format: minutes (e.g., '30m'), hours (e.g., '2h'), or days (e.g., '1d'). Use for time planning and task prioritization.",
                             },
-                            "parent_number": {
-                                "type": "integer",
-                                "description": "Optional parent task number (required for subtasks)",
-                            },
                         },
                         "required": ["description"],
                     },
@@ -452,10 +452,9 @@ class ToolCallHandler:
                         "USE CASE: Call this when user wants to add, change, or remove project tags on an existing task. "
                         "NOT FOR: Creating new tasks, completing tasks, or any other task operations. "
                         "This preserves all existing task components and manages projects intelligently. "
-                        "Supports multiple projects, prevents duplicates, and groups them together. "
                         "Empty array or empty strings are NOOPs (no changes). "
-                        "Use '-project' syntax to remove specific projects. "
-                        "PREFERRED METHOD: Use this instead of append_to_task() when adding project tags (+project). "
+                        "Use '-project' syntax to remove specific projects. with `projects=['-projectname']`"
+                        "PREFERRED METHOD: Use this instead of append_to_task() when adding project tags (+projectname). "
                         "This tool properly manages project organization and prevents formatting issues. "
                         "IMPORTANT: Use list_tasks() first "
                         "to find the correct task number if user doesn't specify it. "
@@ -479,39 +478,6 @@ class ToolCallHandler:
                 },
                 "progress_description": "🏷️ Setting project tags for task #{task_number}...",
             },
-            {
-                "type": "function",
-                "function": {
-                    "name": "set_parent",
-                    "description": (
-                        "Set or update the parent task number for an EXISTING task by intelligently rewriting it. "
-                        "USE CASE: Call this when user wants to add, change, or remove a parent task relationship on an existing task. "
-                        "NOT FOR: Creating new tasks, completing tasks, or any other task operations. "
-                        "This preserves all existing task components (priority, projects, contexts, due date, etc.) "
-                        "while updating or adding the parent relationship. Use None to remove the parent. "
-                        "PREFERRED METHOD: Use this instead of append_to_task() when adding parent tags (parent:XX). "
-                        "This tool properly manages parent relationships and prevents formatting issues. "
-                        "IMPORTANT: Use list_tasks() first "
-                        "to find the correct task number if user doesn't specify it. "
-                        "Parent task numbers should be provided as integers (e.g., 12 not 'parent:12')."
-                    ),
-                    "parameters": {
-                        "type": "object",
-                        "properties": {
-                            "task_number": {
-                                "type": "integer",
-                                "description": "The line number of the task to modify (required)",
-                            },
-                            "parent_number": {
-                                "type": "integer",
-                                "description": "Parent task number to set, or null to remove parent (required)",
-                            },
-                        },
-                        "required": ["task_number", "parent_number"],
-                    },
-                },
-                "progress_description": "🔗 Setting parent task {parent_number} for task #{task_number}...",
-            },
             {
                 "type": "function",
                 "function": {
@@ -626,13 +592,14 @@ class ToolCallHandler:
                     "name": "create_completed_task",
                     "description": (
                         "Create a task and immediately mark it as completed. "
-                        "USE CASE: Call this when user says they completed something on a specific date (e.g., 'I did the laundry today', 'I finished the report yesterday', 'I cleaned the garage last week') "
+                        "USE CASE: WHEN NO MATCH IS FOUND! Call this when user says they completed something on a specific date (e.g., 'I did the laundry today', 'I finished the report yesterday', 'I cleaned the garage last week') "
                         "and you have already researched existing tasks to determine no match exists. "
-                        "WORKFLOW: 1) Use list_tasks() to search for existing tasks, 2) Use list_completed_tasks() to verify it's not already done, "
-                        "3) If no match found, call this tool to create and complete the task in one operation. "
+                        "WORKFLOW: 1) Use list_tasks() to search for existing tasks, "
+                        "2) Use list_completed_tasks() to verify it's not already done, "
+                        "3) If a match is found, use complete_task() to mark it complete, "
+                        "4) If no match found, call this tool to create and complete the task in one operation. "
                         "STRATEGIC CONTEXT: This is a convenience tool for the common pattern of 'I did X on [date]' - "
-                        "it creates a task with the specified completion date and immediately marks it complete. "
-                        "The LLM should handle the research and decision-making about whether to use this tool."
+                        "when no task match is found, it creates a task with the specified completion date and immediately marks it complete. "
                     ),
                     "parameters": {
                         "type": "object",
@@ -653,10 +620,6 @@ class ToolCallHandler:
                                 "type": "string",
                                 "description": "Optional context name (without the @ symbol) for new task creation",
                             },
-                            "parent_number": {
-                                "type": "integer",
-                                "description": "Optional parent task number (required for subtasks)",
-                            },
                         },
                         "required": ["description"],
                     },
@@ -690,6 +653,42 @@ class ToolCallHandler:
                 },
                 "progress_description": "🔄 Restoring completed task #{task_number}...",
             },
+            {
+                "type": "function",
+                "function": {
+                    "name": "solve_math",
+                    "description": (
+                        "Perform mathematical calculations and symbolic reasoning using SymPy. "
+                        "USE CASE: Call this when user asks for mathematical calculations, equation solving, "
+                        "algebraic simplification, calculus operations, or any mathematical reasoning. "
+                        "CAPABILITIES: "
+                        "• Basic arithmetic: '2 + 3 * 4', 'sqrt(16)', '2^3' "
+                        "• Algebraic simplification: 'x^2 + 2*x + 1', 'sin(x)^2 + cos(x)^2' "
+                        "• Equation solving: 'x^2 - 4 = 0', '2*x + 3 = 7' "
+                        "• Calculus: 'derivative of x^2', 'integral of sin(x)', 'limit of 1/x as x approaches 0' "
+                        "• Statistics: 'normal distribution probability', 'mean of [1,2,3,4,5]' "
+                        "• Units and constants: 'convert 100 km to miles', 'speed of light in m/s' "
+                        "The tool automatically detects the type of mathematical operation needed. "
+                        "For complex expressions, provide the mathematical expression as a string. "
+                        "The operation parameter is optional and can specify: 'simplify', 'solve', 'integrate', 'differentiate', 'evaluate', 'stats'."
+                    ),
+                    "parameters": {
+                        "type": "object",
+                        "properties": {
+                            "expression": {
+                                "type": "string",
+                                "description": "The mathematical expression to evaluate or manipulate (required)",
+                            },
+                            "operation": {
+                                "type": "string",
+                                "description": "Optional operation type: 'simplify', 'solve', 'integrate', 'differentiate', 'evaluate', 'matrix', 'stats' (auto-detected if not specified)",
+                            },
+                        },
+                        "required": ["expression"],
+                    },
+                },
+                "progress_description": "🧮 Solving mathematical expression: {expression}...",
+            },
         ]
 
     def _get_calendar(self, month: int, year: int) -> str:
@@ -827,6 +826,19 @@ class ToolCallHandler:
             # If we can't parse it, return today's date as fallback
             return today.strftime("%Y-%m-%d")
 
+    def _solve_math(self, expression: str, operation: Optional[str] = None) -> str:
+        """
+        Perform mathematical calculations and symbolic reasoning using SymPy.
+
+        Args:
+            expression: The mathematical expression to evaluate or manipulate
+            operation: Optional operation type (auto-detected if not specified)
+
+        Returns:
+            The result of the mathematical operation as a string
+        """
+        return self.math_solver.solve_math(expression, operation)
+
     def _format_tool_signature(self, tool_name: str, arguments: Dict[str, Any]) -> str:
         """Format tool signature with parameters for logging."""
         if not arguments:
@@ -939,13 +951,13 @@ class ToolCallHandler:
             "set_due_date": self.todo_manager.set_due_date,
             "set_context": self.todo_manager.set_context,
             "set_project": self.todo_manager.set_project,
-            "set_parent": self.todo_manager.set_parent,
             "move_task": self.todo_manager.move_task,
             "archive_tasks": self.todo_manager.archive_tasks,
             "parse_date": self._parse_date,
             "get_calendar": self._get_calendar,
             "create_completed_task": self.todo_manager.create_completed_task,
             "restore_completed_task": self.todo_manager.restore_completed_task,
+            "solve_math": self._solve_math,
         }
 
         if tool_name not in method_map:
@@ -963,12 +975,31 @@ class ToolCallHandler:
 
         method = method_map[tool_name]
 
+        # Filter arguments to only include those accepted by the method
+        import inspect
+
+        try:
+            sig = inspect.signature(method)
+            valid_params = set(sig.parameters.keys())
+            filtered_arguments = {
+                k: v for k, v in arguments.items() if k in valid_params
+            }
+
+            if self.logger and filtered_arguments != arguments:
+                self.logger.debug(
+                    f"Filtered arguments from {arguments} to {filtered_arguments}"
+                )
+        except Exception as e:
+            if self.logger:
+                self.logger.warning(f"Failed to filter arguments for {tool_name}: {e}")
+            filtered_arguments = arguments
+
         # Log method call details
         if self.logger:
             self.logger.debug(f"Calling method: {tool_name}")
 
         try:
-            result = method(**arguments)
+            result = method(**filtered_arguments)
 
             # Log successful output at DEBUG level
             if self.logger:
